@@ -41,7 +41,7 @@ def identifier_selector(dataset: Dataset) -> Identifier:
         if identifier.is_me(dataset):
             return identifier
 
-    raise NotImplementedError(f"Unalble to identify {dataset.src}")
+    raise NotImplementedError(f"Unable to identify {dataset.src}")
 
 
 def identify(dataset: Dataset) -> Dataset:
@@ -49,7 +49,7 @@ def identify(dataset: Dataset) -> Dataset:
         if identifier.is_me(dataset):
             return identifier.FORMAT
 
-    raise NotImplementedError(f"Unalble to identify {dataset.src}")
+    raise NotImplementedError(f"Unable to identify {dataset.src}")
 
 
 class PB(Identifier):
@@ -63,7 +63,10 @@ class PB(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        path = dataset.src
+        if isinstance(dataset.src, str):
+            path = Path(dataset.src)
+        else:
+            path = dataset.src
 
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
@@ -93,7 +96,10 @@ class NPY(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        path = dataset.src
+        if isinstance(dataset.src, str):
+            path = Path(dataset.src)
+        else:
+            path = dataset.src
 
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
@@ -116,7 +122,10 @@ class NPYDIR(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        path = dataset.src
+        if isinstance(dataset.src, str):
+            path = Path(dataset.src)
+        else:
+            path = dataset.src
 
         if not (isinstance(path, Path) and path.exists() and path.is_dir()):
             return False
@@ -138,7 +147,11 @@ class NPZ(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        path = dataset.src
+        if isinstance(dataset.src, str):
+            path = Path(dataset.src)
+        else:
+            path = dataset.src
+
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
         if str(path).lower().endswith('.npy'):
@@ -254,8 +267,10 @@ class KerasDatasetObject(Identifier):
         # each record is a np.ndarray object
         if isinstance(ds, (tuple, list)):
             if len(ds) == 2 and len(ds[0]) == 2 and len(ds[1]) == 2:
-                if all([isinstance(x, np.ndarray) for x in [ds[0][0], ds[0][1],
-                                                            ds[1][0], ds[1][1]]]):
+                if all([
+                        isinstance(x, np.ndarray)
+                        for x in [ds[0][0], ds[0][1], ds[1][0], ds[1][1]]
+                ]):
                     return True
         return False
 
