@@ -56,6 +56,7 @@ class FileSerializer(Serializer):
         dest = self.get_param('dest')
 
         if dataset.src.is_file():
+            dest = dest.with_suffix(dataset.src.suffix)
             shutil.copy(dataset.src, dest)
         else:
             raise Exception(
@@ -85,6 +86,7 @@ class DirSerializer(Serializer):
 
         if dataset.src.is_dir():
             # Zip the dir if the model is in dir form
+            dest = dest.with_suffix('.zip')
             tmp_path = Path(get_tmp_path()[:-1])
             shutil.make_archive(str(tmp_path), 'zip', dataset.src)
             shutil.move(str(tmp_path) + '.zip', dest)
