@@ -49,7 +49,7 @@ def identifier_selector(model: Any) -> Identifier:
     for identifier in Identifier.REGISTRY:
         if identifier.is_me(model):
             return identifier
-    raise NotImplementedError(f"Unalble to identify {model.src}")
+    raise NotImplementedError(f"Unable to identify {model.src}")
 
 
 def identify(model: Any) -> ModelFormat:
@@ -57,7 +57,7 @@ def identify(model: Any) -> ModelFormat:
         if identifier.is_me(model):
             return identifier.FORMAT
 
-    raise NotImplementedError(f"Unalble to identify {model.src}")
+    raise NotImplementedError(f"Unable to identify {model.src}")
 
 
 class H5(Identifier):
@@ -70,7 +70,11 @@ class H5(Identifier):
     def is_me(cls, model: Any) -> bool:
         if model.format == cls.FORMAT:
             return True
-        path = model.src
+
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
 
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
@@ -89,21 +93,25 @@ class ONNX(Identifier):
 
     @classmethod
     def is_me(cls, model: Any):
-
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
-
         if str(path).lower().endswith('.onnx'):
             return True
 
         # Fixme
         with open(path, 'rb') as f:
             d = f.read(4)
-            return d[0] == 8 and d[2:4] in [bytes.fromhex(x) for x in ['1207', '120B']]
+            return d[0] == 8 and d[2:4] in [
+                bytes.fromhex(x) for x in ['1207', '120B']
+            ]
 
 
 class PTH(Identifier):
@@ -121,8 +129,11 @@ class PTH(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
-
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+            
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -155,8 +166,11 @@ class TorchTraced(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
-
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+            
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -187,8 +201,11 @@ class PB(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
-
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+            
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -209,6 +226,7 @@ class PB(Identifier):
 
         return str(path).lower().endswith('.pb')
 
+
 class TFLITE(Identifier):
     """
     Use file extension and magic number to identify the file
@@ -222,8 +240,14 @@ class TFLITE(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+            
 
+        if str(path).lower().endswith(".tflite"):
+            return True
         if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
@@ -247,7 +271,11 @@ class SavedModel(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+
         if not (isinstance(path, Path) and path.exists()):
             return False
 
@@ -270,7 +298,11 @@ class ZippedSavedModel(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        path = model.src
+        if isinstance(model.src, str):
+            path = Path(model.src)
+        else:
+            path = model.src
+
         if not (isinstance(path, Path) and path.exists()):
             return False
 
@@ -312,8 +344,9 @@ class TFSession(Identifier):
         if model.format == cls.FORMAT:
             return True
 
-        return _check_object_type('tensorflow.python.client.session.Session', model.src)
-   
+        return _check_object_type('tensorflow.python.client.session.Session',
+                                  model.src)
+
 
 class KerasModel(Identifier):
     '''Use python MRO to check if it contains specific str
