@@ -3,8 +3,7 @@ from pathlib import Path
 from abc import abstractmethod
 import shutil
 from dataclasses import dataclass
-import zipfile    
-
+import zipfile
 
 from loguru import logger
 
@@ -26,6 +25,7 @@ class MetadataRetriverRegistry(type):
 
 
 class ModelMeta:
+
     def __init__(self, inputs: List[Tensor], outputs: List[Tensor]):
         self.inputs = inputs
         self.outputs = outputs
@@ -52,8 +52,7 @@ class MetadataRetriver(metaclass=MetadataRetriverRegistry):
         logger.info(f"Inputs of {model.name}: {inputs}")
         outputs = self.retrive_outputs(model)
         logger.info(f"Outputs of {model.name}: {outputs}")
-        return ModelMeta(inputs=inputs,
-                         outputs=outputs)
+        return ModelMeta(inputs=inputs, outputs=outputs)
 
 
 def metadataretriver_selector(model: Model) -> MetadataRetriver:
@@ -98,8 +97,10 @@ class H5(MetadataRetriver):
         from tensorflow import keras  # type: ignore[import]
         _model = keras.models.load_model(model.src)
 
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in _model.inputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in _model.inputs
+        ]
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
         # from tensorflow import keras
@@ -112,32 +113,44 @@ class H5(MetadataRetriver):
         from tensorflow import keras  # type: ignore[import]
         _model = keras.models.load_model(model.src)
 
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in _model.outputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in _model.outputs
+        ]
 
 
 class ONNX(MetadataRetriver):
 
     FORMAT = ModelFormat.ONNX
+
     def retrive_inputs(self, model: Model) -> List[Tensor]:
         import onnx
         onnx_model = onnx.load(model.src)
 
         input_all = [node.name for node in onnx_model.graph.input]
-        input_initializer =  [node.name for node in onnx_model.graph.initializer]
-        net_feed_input = list(set(input_all)  - set(input_initializer))
+        input_initializer = [node.name for node in onnx_model.graph.initializer]
+        net_feed_input = list(set(input_all) - set(input_initializer))
 
-        return [Tensor(x, tuple(), ModelDataType.NON_SPECIFIED) for x in net_feed_input]
+        res = []
+        for input in onnx_model.graph.input:
+            if input.name in net_feed_input:
+                res.append(
+                    Tensor(
+                        input.name,
+                        tuple([
+                            xx.dim_value
+                            for xx in input.type.tensor_type.shape.dim
+                        ]), ModelDataType.NON_SPECIFIED))
+
+        return res
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
         import onnx
         model = onnx.load(model.src)
-        output =[node.name for node in model.graph.output]
-
+        output = [node.name for node in model.graph.output]
         return [Tensor(x, tuple(), ModelDataType.NON_SPECIFIED) for x in output]
 
 
-
 class PTH(MetadataRetriver):
 
     FORMAT = ModelFormat.PTH
@@ -199,12 +212,16 @@ class PB(MetadataRetriver):
             if len(op.inputs) == 0 and op.type != 'Const':
                 inputs.append(op)
 
-        return [Tensor(name=x.name, shape=tuple(x.outputs[0].shape.as_list()),
-                       dtype=x.outputs[0].dtype) for x in inputs]
+        return [
+            Tensor(name=x.name,
+                   shape=tuple(x.outputs[0].shape.as_list()),
+                   dtype=x.outputs[0].dtype) for x in inputs
+        ]
         """
         >>> [x.size for x in graph_def.node[0].attr['shape'].shape.dim]
         [-1, 96, 96, 3]
         """
+
     def retrive_outputs(self, model: Model) -> List[Tensor]:
         import tensorflow as tf
         ops = self._load_graph(model.src)
@@ -221,8 +238,11 @@ class PB(MetadataRetriver):
 
         outputs = list(outputs_set)
 
-        return [Tensor(name=x.name, shape=tuple(x.outputs[0].shape.as_list()),
-                       dtype=x.outputs[0].dtype) for x in outputs]
+        return [
+            Tensor(name=x.name,
+                   shape=tuple(x.outputs[0].shape.as_list()),
+                   dtype=x.outputs[0].dtype) for x in outputs
+        ]
 
 
 class SavedModel(MetadataRetriver):
@@ -233,8 +253,10 @@ class SavedModel(MetadataRetriver):
         from tensorflow import keras  # type: ignore[import]
         _model = keras.models.load_model(model.src)
 
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in _model.inputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in _model.inputs
+        ]
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
         # from tensorflow import keras
@@ -247,8 +269,10 @@ class SavedModel(MetadataRetriver):
         from tensorflow import keras  # type: ignore[import]
         _model = keras.models.load_model(model.src)
 
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in _model.outputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in _model.outputs
+        ]
 
 
 class ZippedSavedModel(MetadataRetriver):
@@ -260,28 +284,32 @@ class ZippedSavedModel(MetadataRetriver):
 
         temp = get_tmp_path()
 
-        with zipfile.ZipFile(model.src, 'r') as zip_ref:  # type: ignore[arg-type]
+        with zipfile.ZipFile(model.src,
+                             'r') as zip_ref:  # type: ignore[arg-type]
             zip_ref.extractall(temp)
 
-
         _model = keras.models.load_model(temp)
 
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in _model.inputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in _model.inputs
+        ]
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
         from tensorflow import keras  # type: ignore[import]
 
         temp = get_tmp_path()
 
-        with zipfile.ZipFile(model.src, 'r') as zip_ref:  # type: ignore[arg-type]
+        with zipfile.ZipFile(model.src,
+                             'r') as zip_ref:  # type: ignore[arg-type]
             zip_ref.extractall(temp)
 
-
         _model = keras.models.load_model(temp)
 
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in _model.outputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in _model.outputs
+        ]
 
 
 class TFKerasModel(MetadataRetriver):
@@ -289,12 +317,16 @@ class TFKerasModel(MetadataRetriver):
     FORMAT = ModelFormat.TF_KERAS_MODEL
 
     def retrive_inputs(self, model: Model) -> List[Tensor]:
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in model.src.inputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in model.src.inputs
+        ]
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in model.src.outputs]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in model.src.outputs
+        ]
 
 
 class KerasModel(MetadataRetriver):
@@ -305,12 +337,16 @@ class KerasModel(MetadataRetriver):
     FORMAT = ModelFormat.KERAS_MODEL
 
     def retrive_inputs(self, model: Model) -> List[Tensor]:
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in model.src.inputs]   # type: ignore[union-attr]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in model.src.inputs
+        ]  # type: ignore[union-attr]
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
-        return [Tensor(name=x.name, shape=tuple(x.shape.as_list()),
-                       dtype=x.dtype) for x in model.src.outputs]  # type: ignore[union-attr]
+        return [
+            Tensor(name=x.name, shape=tuple(x.shape.as_list()), dtype=x.dtype)
+            for x in model.src.outputs
+        ]  # type: ignore[union-attr]
 
 
 class PytorchModel(MetadataRetriver):
@@ -366,22 +402,23 @@ class TFLiteModel(MetadataRetriver):
     FORMAT = ModelFormat.TFLITE
 
     def retrive_inputs(self, model: Model) -> List[Tensor]:
+
         try:
             import tflite_runtime.interpreter as tflite
-            interpreter = tflite.Interpreter(model_path=model.src)
+            interpreter = tflite.Interpreter(model_path=str(model.src))
         except ModuleNotFoundError:
             import tensorflow as tf
-            interpreter = tf.lite.Interpreter(model_path=model.src)
-
-        return [[i["name"], i["shape"].tolist(), i['dtype']] for i in interpreter.get_input_details()]
-
+            interpreter = tf.lite.Interpreter(model_path=str(model.src))
+        return [Tensor(i["name"], i["shape"].tolist(), i['dtype'])
+                for i in interpreter.get_input_details()]
 
     def retrive_outputs(self, model: Model) -> List[Tensor]:
         try:
             import tflite_runtime.interpreter as tflite
-            interpreter = tflite.Interpreter(model_path=model.src)
+            interpreter = tflite.Interpreter(model_path=str(model.src))
         except ModuleNotFoundError:
             import tensorflow as tf
-            interpreter = tf.lite.Interpreter(model_path=model.src)
+            interpreter = tf.lite.Interpreter(model_path=str(model.src))
 
-        return [[i["name"], i["shape"].tolist(), i['dtype']] for i in interpreter.get_output_details()]
+        return [Tensor(i["name"], i["shape"].tolist(), i['dtype'])
+                for i in interpreter.get_output_details()]
