@@ -30,15 +30,15 @@ class ModelPackage:
     """
 
     def __init__(
-            self,
-            model: Union[object, str, Path, Model],
-            dataset: Union[object, str, Path, Dataset],
-            model_format: ModelFormat = ModelFormat.NON_SPECIFIED,
-            sample_format: DatasetFormat = DatasetFormat.NON_SPECIFIED,
-            #  [name: str, shape:Tuple, dtype:ModelDataType]
-            model_inputs: List[Union[List, Tuple, Tensor]] = [],
-            #  [name: str, shape:Tuple, dtype:ModelDataType]
-            model_outputs: List[Union[List, Tuple, Tensor]] = []):
+        self,
+        model: Union[object, str, Path, Model],
+        dataset: Union[object, str, Path, Dataset],
+        model_format: ModelFormat = ModelFormat.NON_SPECIFIED,
+        sample_format: DatasetFormat = DatasetFormat.NON_SPECIFIED,
+        #  [name: str, shape:Tuple, dtype:ModelDataType]
+        model_inputs: List[Union[List, Tuple, Tensor]] = [],
+        #  [name: str, shape:Tuple, dtype:ModelDataType]
+        model_outputs: List[Union[List, Tuple, Tensor]] = []):
 
         self._src_model = model
         self._src_dataset = dataset
@@ -122,6 +122,10 @@ class ModelPackage:
         logger.debug(self.model.format.name)
 
     def __encapsulate_dataset(self, dataset_format: DatasetFormat):
+        if self._src_dataset is None:
+            self.dataset = Dataset(None)
+            return
+
         # Convert to a Dataset object if it is not
         if isinstance(self._src_dataset, Dataset):
             self.dataset = self._src_dataset
@@ -131,6 +135,7 @@ class ModelPackage:
             self.dataset = Dataset(self._src_dataset)
 
         # specify model format or identify it automatically
+
         if not dataset_format == DatasetFormat.NON_SPECIFIED:
             self.dataset.format = dataset_format
         else:
