@@ -9,7 +9,6 @@ from loguru import logger
 from .core.modelpackage import ModelPackage
 from .core.dataset.dataset import Dataset
 
-
 from .core.model import ModelFormat, TF_MODEL_FORMATS, ModelDataType
 from .core.model.model import Tensor
 
@@ -23,7 +22,7 @@ from .core.common import get_tmp_path, get_temp_base
 from .config import default_builder, default_builder_params
 
 
-def login(api_key: str, password: str=""):
+def login(api_key: str, password: str = ""):
     os.environ['ONNC_API_USER'] = api_key
     os.environ['ONNC_API_PASSWD'] = password
 
@@ -33,7 +32,10 @@ def get_api_key():
 
 
 class Project:
-    def __init__(self, name, builder=default_builder,
+
+    def __init__(self,
+                 name,
+                 builder=default_builder,
                  builder_params=default_builder_params):
         self.builder = builder(*builder_params)
 
@@ -64,6 +66,8 @@ class Project:
 
     @classmethod
     def get_dataset_meta(cls, model_package):
+        if not model_package.dataset:
+            return
         dataset_meta = {
             "shape": model_package.dataset.shape,
             "format": model_package.dataset.format.name
@@ -74,16 +78,17 @@ class Project:
 
         return dataset_meta
 
-    def add_model(self,
-                  model: Union[object, str, Path],
-                  samples: Union[object, str, Path, Dataset],
-                  model_format: ModelFormat = ModelFormat.NON_SPECIFIED,
-                  sample_format: DatasetFormat = DatasetFormat.NON_SPECIFIED,
-                  # [name: str, shape:Tuple, dtype:ModelDataType]
-                  model_inputs: List[Union[List, Tuple, Tensor]] = [],
-                  # [name: str, shape:Tuple, dtype:ModelDataType]
-                  model_outputs: List[Union[List, Tuple, Tensor]] = [],
-                  inputs_as_nchw: Union[str, bool, None, List[str]] = None):
+    def add_model(
+            self,
+            model: Union[object, str, Path],
+            samples: Union[object, str, Path, Dataset, None],
+            model_format: ModelFormat = ModelFormat.NON_SPECIFIED,
+            sample_format: DatasetFormat = DatasetFormat.NON_SPECIFIED,
+            # [name: str, shape:Tuple, dtype:ModelDataType]
+            model_inputs: List[Union[List, Tuple, Tensor]] = [],
+            # [name: str, shape:Tuple, dtype:ModelDataType]
+            model_outputs: List[Union[List, Tuple, Tensor]] = [],
+            inputs_as_nchw: Union[str, bool, None, List[str]] = None):
         """Add a model and its corresponding calibration samples.
 
         :param Union[object, str, Path] model:
@@ -126,9 +131,8 @@ class Project:
 
 
         """
-        model_package = ModelPackage(model, samples,
-                                     model_format, sample_format,
-                                     model_inputs, model_outputs)
+        model_package = ModelPackage(model, samples, model_format,
+                                     sample_format, model_inputs, model_outputs)
 
         model_tmp_path = Path(get_tmp_path())
         dataset_tmp_path = Path(get_tmp_path())
@@ -145,6 +149,7 @@ class Project:
 
         self.builder.calibrate(model_id, params={})
         self.builder.compile(model_id, params={})
+        return model_meta
 
     def compile(self, target: str, **params):
         """Trigger the compilation process and transform the given
@@ -191,5 +196,8 @@ class Project:
     def prune(self, params={}):
         raise NotImplementedError("Model pruning is not implemented yet.")
 
-    def __del__(self):
-        shutil.rmtree(get_temp_base())
+    """
+    This require fix? Always raise error while compile
+    """
+    # def __del__(self):
+    #     shutil.rmtree(get_temp_base())
